@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Date         : 2020-12-30
 # @Author       : AaronJny
-# @LastEditTime : 2021-03-13
+# @LastEditTime : 2021-03-16
 # @FilePath     : /LuWu/luwu/core/models/classifier/__init__.py
 # @Desc         :
 import os
@@ -22,7 +22,7 @@ class LuwuImageClassifier:
     def __init__(
         self,
         origin_dataset_path: str = "",
-        target_dataset_path: str = "",
+        tfrecord_dataset_path: str = "",
         model_save_path: str = "",
         validation_split: float = 0.2,
         batch_size: int = 32,
@@ -30,31 +30,34 @@ class LuwuImageClassifier:
         project_id: int = 0,
         image_size: int = 224,
         do_fine_tune=False,
+        with_image_net=True,
         **kwargs,
     ):
         """
         Args:
             origin_dataset_path (str): 处理前的数据集路径
-            target_dataset_path (str): 处理后的数据集路径
+            tfrecord_dataset_path (str): 处理后的数据集路径
             model_save_path (str): 模型保存路径
             validation_split (float): 验证集切割比例
             batch_size (int): mini batch 大小
             epochs (int): 训练epoch数
             project_id (int): 训练项目编号
+            with_image_net (bool): 是否使用imagenet的均值初始化数据
         """
         self._call_code = ""
         self.project_id = project_id
         self.do_fine_tune = do_fine_tune
+        self.with_image_net = with_image_net
         origin_dataset_path = file_util.abspath(origin_dataset_path)
-        target_dataset_path = file_util.abspath(target_dataset_path)
+        tfrecord_dataset_path = file_util.abspath(tfrecord_dataset_path)
         model_save_path = file_util.abspath(model_save_path)
         self.image_size = image_size
         self.origin_dataset_path = origin_dataset_path
         # 当未给定处理后数据集的路径时，默认保存到原始数据集相同路径
-        if target_dataset_path:
-            self.target_dataset_path = target_dataset_path
+        if tfrecord_dataset_path:
+            self.tfrecord_dataset_path = tfrecord_dataset_path
         else:
-            self.target_dataset_path = origin_dataset_path
+            self.tfrecord_dataset_path = origin_dataset_path
         # 当未给定模型保存路径时，默认保存到处理后数据集相同路径
         if self.project_id:
             self.project_save_name = f"luwu-classification-project-{self.project_id}"
@@ -66,14 +69,14 @@ class LuwuImageClassifier:
             )
         else:
             self.project_save_path = os.path.join(
-                self.target_dataset_path, self.project_save_name
+                self.tfrecord_dataset_path, self.project_save_name
             )
         self.model_save_path = os.path.join(self.project_save_path, "best_weights.h5")
         self.validation_split = validation_split
         self.batch_size = batch_size
         self.epochs = epochs
         file_util.mkdirs(self.project_save_path)
-        file_util.mkdirs(self.target_dataset_path)
+        file_util.mkdirs(self.tfrecord_dataset_path)
 
     def build_model(self) -> tf.keras.Model:
         """构建模型
@@ -83,6 +86,11 @@ class LuwuImageClassifier:
         """
         raise NotImplementedError
 
+    @property
+    def kaggle_envs(self):
+        """返回使用kaggle运行时的需要的参数"""
+        return {}
+
     def preprocess_dataset(self):
         """对数据集进行预处理"""
         # 读取原始数据
@@ -97,10 +105,10 @@ class LuwuImageClassifier:
         }
         # 先判断tfrecord是否存在
         self.target_train_dataset_path = os.path.join(
-            self.target_dataset_path, "train_dataset"
+            self.tfrecord_dataset_path, "train_dataset"
         )
         self.target_dev_dataset_path = os.path.join(
-            self.target_dataset_path, "dev_dataset"
+            self.tfrecord_dataset_path, "dev_dataset"
         )
         # if (
         #     os.path.exists(self.target_train_dataset_path)
@@ -130,12 +138,14 @@ class LuwuImageClassifier:
         self.train_dataset = ImageClassifierDataGnenrator(
             self.target_train_dataset_path,
             batch_size=self.batch_size,
-            do_fine_tune=self.do_fine_tune,
+            image_size=self.image_size,
+            with_image_net=self.with_image_net,
         )
         self.dev_dataset = ImageClassifierDataGnenrator(
             self.target_dev_dataset_path,
             batch_size=self.batch_size,
-            do_fine_tune=self.do_fine_tune,
+            image_size=self.image_size,
+            with_image_net=self.with_image_net,
         )
 
     def train(self):
